pub struct StagedEvent {
pub id: String,
pub source: String,
pub content: String,
pub meta: Option<String>,
pub timestamp: i64,
}Fields
id: Stringsource: Stringcontent: Stringmeta: Option<String>timestamp: i64Implementations
Sourceimpl StagedEvent
impl StagedEvent
pub fn new(source: &str, content: &str, meta: Option<&str>) -> Self
Sourcepub fn timestamp_utc(&self) -> DateTime<Utc>
pub fn timestamp_utc(&self) -> DateTime<Utc>
Return the event timestamp as a DateTime<Utc>.
Sourcepub fn save_to_file(&self, staging_dir: &Path) -> Result<(), Error>
pub fn save_to_file(&self, staging_dir: &Path) -> Result<(), Error>
Persist this staged event to disk as a JSON file.
Sourcepub fn load_from_file(id: &str, staging_dir: &Path) -> Result<Self, Error>
pub fn load_from_file(id: &str, staging_dir: &Path) -> Result<Self, Error>
Load a staged event by its ID from the staging directory.
Sourcepub fn from_file(path: &Path) -> Result<Self, Error>
pub fn from_file(path: &Path) -> Result<Self, Error>
Load a staged event from an arbitrary file path.